@@ -1,8 +1,5 @@
 context ("time formats")
 
-test_all <- (identical (Sys.getenv ("MPADGE_LOCAL"), "true") |
-    identical (Sys.getenv ("GITHUB_WORKFLOW"), "test-coverage"))
-
 nthr <- data.table::setDTthreads (1L)
 
 test_that ("convert-time", {
