@@ -2,9 +2,6 @@ context ("traveltimes")
 
 nthr <- data.table::setDTthreads (1L)
 
-test_all <- (identical (Sys.getenv ("MPADGE_LOCAL"), "true") |
-    identical (Sys.getenv ("GITHUB_WORKFLOW"), "test-coverage"))
-
 berlin_gtfs_to_zip ()
 f <- fs::path (fs::path_temp (), "vbb.zip")
 g <- extract_gtfs (f, quiet = TRUE)
